<?xml version="1.0"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml" xmlns:xhtml="http://www.w3.org/1999/xhtml">
	<xsl:output method="xml"
							doctype-system="xhtml-math-svg.dtd"
							doctype-public="-//W3C//DTD XHTML 1.1 plus MathML 2.0 plus SVG 1.1//EN"
     					encoding="UTF-8"
     					indent="yes"/>
     					
<!-- ******************************************************************************************** -->
<!-- MiLCA XSLT Stylesheet -->
<!-- Fragen und Anregungen: Maik Stuehrenberg, JLU Giessen -->
<!-- maik.stuehrenberg@uni-giessen.de -->
<!-- zuletzt geaendert am: 30-01-2003, 10:45 -->
<!-- ******************************************************************************************** -->

	<xsl:strip-space elements="*"/>
	<xsl:preserve-space elements="xsl:text"/>

<!-- Template fuer das root-Element LearningObject -->
<!-- Die Verarbeitung erfolgt in mehreren Schritten: -->
<!-- 1. Erzeugung einer Ausgabedatei -->
<!-- 2. Erstellung eines Inhaltsverzeichnisses -->
<!-- Dabei wird jeweils dem AggregationLevel unterschieden -->
	<xsl:template match="LearningObject">
		<xsl:choose>
			<xsl:when test="MetaData/General/@AggregationLevel>=3">
<!-- Level 3 und hoeher erhalten ein Inhaltsverzeichnis -->			
				<xsl:variable name="index" select="concat(MetaData/General/Identifier/@Entry,'.xhtml')"/>
				<xsl:document href="{$index}">
					<html>
						<head>
							<xsl:apply-templates select="MetaData"/>
							<link type="text/css" rel="stylesheet">
								<xsl:attribute name="href">
									<xsl:value-of select="LayoutInformation/@CSS-URL"/>
								</xsl:attribute>
							</link>
						</head>
						<body>
							<xsl:if test="Content/LearningObject[MetaData/General/@AggregationLevel>=2]">					
								<p>
									<b>
										<a>
											<xsl:attribute name="href">
												<xsl:value-of select="concat(Content/LearningObject/MetaData/General/Identifier/@Entry,'.xhtml')"/>
											</xsl:attribute>
											&gt;&gt;
										</a>
									</b>
								</p>
							</xsl:if>
							<h1>
								<xsl:value-of select="MetaData/General/Title"/>
							</h1>
							<p>
								<xsl:choose>
									<xsl:when test="MetaData/General/Language='de'">
										<b>Zusammenfassung:</b>
									</xsl:when>
									<xsl:when test="MetaData/General/Language='en'">
										<b>Abstract:</b>
									</xsl:when>
									<xsl:otherwise>
										<b>Abstract:</b>
									</xsl:otherwise>
								</xsl:choose>
								<br/>
								<span class="Description">
									<xsl:apply-templates select="MetaData/General/Description"/>
								</span>
							</p>
<!-- Erzeugen des Inhaltsverzeichnisses -->
<!-- Jedes LearningObject mit einem AggregationLevel > 1 wird in das Inhaltsverzeichnis aufgenommen -->					
							<xsl:choose>
								<xsl:when test="MetaData/General/Language='de'">
									<h2>Inhalt</h2>
								</xsl:when>
								<xsl:when test="MetaData/General/Language='en'">
									<h2>Table of Contents</h2>
								</xsl:when>
								<xsl:otherwise>
									<h2>Table of Contents</h2>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:for-each select="Content/LearningObject">
								<xsl:choose>
									<xsl:when test="MetaData/General/@AggregationLevel>1">
										<xsl:variable name="LOfile" select="concat(MetaData/General/Identifier/@Entry,'.xhtml')"/>
										<p>
											<a>
												<xsl:attribute name="href">	
													<xsl:value-of select="$LOfile"/>
												</xsl:attribute>
												<xsl:value-of select="MetaData/General/Title"/>
											</a>
											<br/>
											<span class="Description">
												<xsl:apply-templates select="MetaData/General/Description"/>
											</span>
										</p>								
									</xsl:when>
								</xsl:choose>
							</xsl:for-each>
							<xsl:apply-templates select="Test"/>
							<xsl:apply-templates select="Bibliography"/>
							<xsl:apply-templates select="Glossary"/>
							<xsl:if test="Content/LearningObject[MetaData/General/@AggregationLevel>=2]">					
								<p>
									<b>
										<a>
											<xsl:attribute name="href">
												<xsl:value-of select="concat(Content/LearningObject/MetaData/General/Identifier/@Entry,'.xhtml')"/>
											</xsl:attribute>
											&gt;&gt;
										</a>
									</b>
								</p>
							</xsl:if>
						</body>
					</html>
				</xsl:document>
			</xsl:when>
			<xsl:when test="MetaData/General/@AggregationLevel=2">
<!-- LearningObjects mit Level 2 werden als HTML-Seiten ausgegeben -->			
				<xsl:variable name="LO" select="concat(MetaData/General/Identifier/@Entry,'.xhtml')"/>
				<xsl:document href="{$LO}">
					<html>
						<head>
							<xsl:apply-templates select="MetaData"/>
							<link type="text/css" rel="stylesheet">
								<xsl:attribute name="href">
									<xsl:value-of select="LayoutInformation/@CSS-URL"/>
								</xsl:attribute>
							</link>
						</head>
						<body>
<!-- Einbindung von zurueck, weiter, nach oben Verweisen -->
							<xsl:if test="following-sibling::LearningObject[MetaData/General/@AggregationLevel>=1]">							
								<p>
									<b>
										<a>
											<xsl:attribute name="href">
												<xsl:value-of select="concat(following-sibling::LearningObject/MetaData/General/Identifier/@Entry,'.xhtml')"/>
											</xsl:attribute>									
											&gt;&gt;									
										</a>
										<a>
											<xsl:attribute name="href">
												<xsl:value-of select="concat(//MetaData/General/Identifier/@Entry,'.xhtml')"/>
											</xsl:attribute>
											TOC
										</a>
									</b>
								</p>
							</xsl:if>					
							<h1>
								<xsl:value-of select="MetaData/General/Title"/>
							</h1>
							<p>
								<xsl:choose>
									<xsl:when test="MetaData/General/Language='de'">
										<b>Zusammenfassung:</b>
									</xsl:when>
									<xsl:when test="MetaData/General/Language='en'">
										<b>Abstract:</b>
									</xsl:when>
									<xsl:otherwise>
										<b>Abstract:</b>
									</xsl:otherwise>
								</xsl:choose>
								<br/>
								<span class="Description">
									<xsl:apply-templates select="MetaData/General/Description"/>
								</span>
							</p>
							<xsl:apply-templates select="Content"/>
							<xsl:apply-templates select="Test"/>
							<xsl:apply-templates select="Bibliography"/>
							<xsl:apply-templates select="Glossary"/>
							<xsl:if test="following-sibling::LearningObject[MetaData/General/@AggregationLevel>=1]">							
								<p>
									<b>
										<a>
											<xsl:attribute name="href">
												<xsl:value-of select="concat(following-sibling::LearningObject/MetaData/General/Identifier/@Entry,'.xhtml')"/>
											</xsl:attribute>									
											&gt;&gt;									
										</a>
									</b>
								</p>
							</xsl:if>	
						</body>
					</html>
				</xsl:document>
			</xsl:when>
			<xsl:when test="MetaData/General/@AggregationLevel=1">
				<xsl:choose>
					<xsl:when test="MetaData/Technical/@Format='image-gif'">
						<img>
							<xsl:attribute name="src">
								<xsl:value-of select="MetaData/Technical/Location"/>
							</xsl:attribute>
							<xsl:attribute name="alt">
								<xsl:value-of select="MetaData/General/Description"/>
							</xsl:attribute>
						</img>
						<div class="Image">
							<xsl:choose>
								<xsl:when test="MetaData/General/Language='de'">
									<xsl:text>Abbildung </xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>Figure </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:number count="LearningObject"/>
							<xsl:text>: </xsl:text>
							<xsl:value-of select="MetaData/General/Title"/>
						</div>
						<div class="Imagetext">
							<xsl:apply-templates select="MetaData/General/Description"/>
						</div>
					</xsl:when>
					<xsl:when test="MetaData/Technical/@Format='image-jpeg'">
						<img>
							<xsl:attribute name="src">
								<xsl:value-of select="MetaData/Technical/Location"/>
							</xsl:attribute>
							<xsl:attribute name="alt">
								<xsl:value-of select="MetaData/General/Description"/>
							</xsl:attribute>
						</img>
						<div class="Image">
							<xsl:choose>
								<xsl:when test="MetaData/General/Language='de'">
									<xsl:text>Abbildung </xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>Figure </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:number count="LearningObject"/>
							<xsl:text>: </xsl:text>
							<xsl:value-of select="MetaData/General/Title"/>
						</div>
						<div class="Imagetext">
							<xsl:apply-templates select="MetaData/General/Description"/>
						</div>
					</xsl:when>		
					<xsl:when test="MetaData/Technical/@Format='image-png'">
						<img>
							<xsl:attribute name="src">
								<xsl:value-of select="MetaData/Technical/Location"/>
							</xsl:attribute>
							<xsl:attribute name="alt">
								<xsl:value-of select="MetaData/General/Description"/>
							</xsl:attribute>
						</img>
						<div class="Image">
							<xsl:choose>
								<xsl:when test="MetaData/General/Language='de'">
									<xsl:text>Abbildung </xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>Figure </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:number count="LearningObject"/>
							<xsl:text>: </xsl:text>
							<xsl:value-of select="MetaData/General/Title"/>
						</div>
						<div class="Imagetext">
							<xsl:apply-templates select="MetaData/General/Description"/>
						</div>
					</xsl:when>
					<xsl:when test="MetaData/Technical/@Format='image-svg-xml'">
						<xsl:copy-of select="document(MetaData/Technical/Location)/*"/>
						<div class="Image">
							<xsl:choose>
								<xsl:when test="MetaData/General/Language='de'">
									<xsl:text>Abbildung </xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>Figure </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:number count="LearningObject"/>
							<xsl:text>: </xsl:text>
							<xsl:value-of select="MetaData/General/Title"/>
						</div>
						<div class="Imagetext">
							<xsl:apply-templates select="MetaData/General/Description"/>
						</div>
					</xsl:when>
					<xsl:when test="MetaData/Technical/@Format='text-xhtml'">
						<xsl:copy-of select="document(MetaData/Technical/Location)/xhtml:html/xhtml:body/*"/>
						<div class="Image">
							<xsl:value-of select="MetaData/General/Title"/>
						</div>
						<div class="Imagetext">
							<xsl:apply-templates select="MetaData/General/Description"/>
						</div>
					</xsl:when>
					<xsl:otherwise>
						<a>
							<xsl:attribute name="href">
								<xsl:value-of select="MetaData/Technical/Location"/>
							</xsl:attribute>
							<xsl:value-of select="MetaData/General/Title"/>
						</a>
					</xsl:otherwise>								
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
		<xsl:apply-templates/>
	</xsl:template>
	
<!-- Template fuer die MetaDaten -->
<!-- In HTML verwendete MetaDaten wie Titel, Autor, Description und Keywords werden weitergerreicht -->
	<xsl:template match="MetaData">
		<xsl:for-each select="Lifecycle/Contribute/Entity">
			<xsl:if test="@Role='Author'">
				<meta name="author">
					<xsl:attribute name="content">
						<xsl:choose>
							<xsl:when test="vCard">
								<xsl:value-of select="vCard/FN"/>		
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</meta>
			</xsl:if>
		</xsl:for-each>
		<xsl:if test="General/@AggregationLevel>1">
			<meta name="description">
				<xsl:attribute name="content">
					<xsl:value-of select="General/Description"/>
				</xsl:attribute>
			</meta>
			<meta name="keywords">
				<xsl:attribute name="content">
					<xsl:for-each select="General/Keyword">
						<xsl:value-of select="."/>
						<xsl:if test="position()!=last()">
							<xsl:text>, </xsl:text>
						</xsl:if>
					</xsl:for-each>
				</xsl:attribute>
			</meta>
			<title>
				<xsl:value-of select="General/Title"/>
			</title>
		</xsl:if>
	</xsl:template>
	
<!-- Template fuer den Inhalt -->
	<xsl:template match="Content">
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="Text">
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="Headline">
		<h2><xsl:apply-templates/></h2>
	</xsl:template>
	
	<xsl:template match="Paragraph">
		<p>
		<xsl:apply-templates/>
		</p>
	</xsl:template>
	
<!-- Besondere Behandlung fuer Absaetze, die in Listen eingebettet sind -->	
	<xsl:template match="Item/Paragraph">
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="Definition/Paragraph">
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="Link">
		<a target="_blank">
			<xsl:attribute name="href">
 				<xsl:value-of select="@Href"/>
 			</xsl:attribute>
 			<xsl:attribute name="title">
 				<xsl:value-of select="@Title"/>
 			</xsl:attribute>
 			<xsl:value-of select="."/>
		</a>
	</xsl:template>
	
<!-- Emph und Strong werden nach HTML durchgereicht -->
<!-- Je nach Grund der Hervorhebung wird eine CSS-Klasse genutzt -->
	<xsl:template match="Emph">
		<em>
			<xsl:choose>
				<xsl:when test="@Reason='Keyword'">
					<xsl:attribute name="class">
						<xsl:text>Keyword</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='Intuition'">
					<xsl:attribute name="class">
						<xsl:text>Intuition</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='MetaLanguageUse'">
					<xsl:attribute name="class">
						<xsl:text>MetaLanguageUse</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='Highlight'">
					<xsl:attribute name="class">
						<xsl:text>Highlight</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates/>
				</xsl:otherwise>
			</xsl:choose>
		</em>
 	</xsl:template>
 	
 	<xsl:template match="Strong">
 		<strong>
 			<xsl:choose>
				<xsl:when test="@Reason='Keyword'">
					<xsl:attribute name="class">
						<xsl:text>Keyword</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='Intuition'">
					<xsl:attribute name="class">
						<xsl:text>Intuition</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='MetaLanguageUse'">
					<xsl:attribute name="class">
						<xsl:text>MetaLanguageUse</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='Highlight'">
					<xsl:attribute name="class">
						<xsl:text>Highlight</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates/>
				</xsl:otherwise>
			</xsl:choose>
 		</strong>
 	</xsl:template>
 	
<!-- Woertliche Zitate -->
<!-- Zitate werden in Anfuehrungszeichen gesetzt -->
<!-- Wenn es eine Referenz gibt, dann wird der Autor der Referenz genannt -->
<!-- Gibt es mehrere Autoren, werden sie durch Kommata getrennt -->
<!-- Anschliessend erfolgt die Nennung des Jahres und einer evtl. vorhandenen Seitenangabe --> 
 	<xsl:template match="Quotation">
 		<xsl:choose>
 			<xsl:when test="@Type='Block'">
				<blockquote>
					<xsl:text>"</xsl:text>
					<xsl:apply-templates/>
					<xsl:text>" </xsl:text>
					<xsl:if test="@Reference_to">
						<a class="Reference">
							<xsl:attribute name="href">
								<xsl:value-of select="concat(id(@Reference_to)/../../MetaData/General/Identifier/@Entry,'.xhtml','#',@Reference_to)"/>
							</xsl:attribute>
							<xsl:choose>
 								<xsl:when test="id(@Reference_to)/Author">
 									<xsl:for-each select="id(@Reference_to)/Author">
 										<xsl:apply-templates select="Family"/>
 										<xsl:choose>
											<xsl:when test="position()!=last()">
												<xsl:text>, </xsl:text>
											</xsl:when>
										</xsl:choose> 				
									</xsl:for-each>
								</xsl:when>
								<xsl:when test="id(@Reference_to)/Editor">
									<xsl:for-each select="id(@Reference_to)/Editor">
 										<xsl:apply-templates select="Family"/>
 										<xsl:choose>
											<xsl:when test="position()!=last()">
												<xsl:text>, </xsl:text>
											</xsl:when>
										</xsl:choose> 				
									</xsl:for-each>
								</xsl:when>
							</xsl:choose>
 							<xsl:text>, </xsl:text>
 							<xsl:apply-templates select="id(@Reference_to)/Year"/>
 							<xsl:if test="@Page">
 								<xsl:text>, S. </xsl:text>
 								<xsl:apply-templates select="@Page"/>
 							</xsl:if>
 						</a>
 					</xsl:if>
				</blockquote>
 			</xsl:when>
 			<xsl:otherwise> 			
 				<xsl:text>"</xsl:text><xsl:apply-templates/><xsl:text>" </xsl:text>
 				<xsl:if test="@Reference_to">
 					<a class="Reference">
 						<xsl:attribute name="href">
								<xsl:value-of select="concat(id(@Reference_to)/../../MetaData/General/Identifier/@Entry,'.xhtml','#',@Reference_to)"/>
						</xsl:attribute>
 						<xsl:text>[</xsl:text>
 						<xsl:choose>
 							<xsl:when test="id(@Reference_to)/Author">
 								<xsl:for-each select="id(@Reference_to)/Author">
 									<xsl:apply-templates select="Family"/>
 									<xsl:choose>
										<xsl:when test="position()!=last()">
											<xsl:text>, </xsl:text>
										</xsl:when>
									</xsl:choose> 				
								</xsl:for-each>
							</xsl:when>
							<xsl:when test="id(@Reference_to)/Editor">
								<xsl:for-each select="id(@Reference_to)/Editor">
 									<xsl:apply-templates select="Family"/>
 									<xsl:choose>
										<xsl:when test="position()!=last()">
											<xsl:text>, </xsl:text>
										</xsl:when>
									</xsl:choose> 				
								</xsl:for-each>
							</xsl:when>
						</xsl:choose>
 						<xsl:text>, </xsl:text>
 						<xsl:apply-templates select="id(@Reference_to)/Year"/>
 						<xsl:if test="@Page">
 							<xsl:text>, S. </xsl:text>
 							<xsl:apply-templates select="@Page"/>
 						</xsl:if>
 						<xsl:text>]</xsl:text>
 					</a>
 				</xsl:if>
 			</xsl:otherwise>
 		</xsl:choose>
 	</xsl:template>
 	
 	<xsl:template match="Entity">
<!-- vCard oder PCDATA ? -->
		<xsl:choose>
			<xsl:when test="vCard">
				<xsl:value-of select="vCard/FN"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates/>
			</xsl:otherwise>
		</xsl:choose>
 	</xsl:template>
 	
 	<xsl:template match="Code">
 		<xsl:choose>
 			<xsl:when test="@Display='Block'">
 				<div class="CodeBlock">
 					<xsl:choose>
 						<xsl:when test="CodeElem">
 							<xsl:for-each select="CodeElem">
								<xsl:value-of select="."/>
								<br/> 							
	 						</xsl:for-each>
 						</xsl:when>
 						<xsl:otherwise>
 							<div class="CodeBlock">
 								<xsl:value-of select="."/>
 							</div>
 						</xsl:otherwise>
 					</xsl:choose>
 				</div>
 			</xsl:when>
 			<xsl:otherwise>
 				<span class="Code">
 					<xsl:value-of select="."/>
 				</span>
			</xsl:otherwise>
 		</xsl:choose>
 	</xsl:template>
 	
 	<xsl:template match="Example[*/Code]">
 		<div class="Example">
			<xsl:choose>
				<xsl:when test="//MetaData/General/Language='de'">
					<xsl:text>Beispiel </xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>Example</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:number count="Example" level="any"/>
			<xsl:text>: </xsl:text>
			<xsl:value-of select="@Id"/>
		</div>
 		<xsl:choose>
 			<xsl:when test="*/Code/@Display='Block'">
 				<xsl:choose>
 					<xsl:when test="*/Code/CodeElem">
 						<xsl:for-each select="*/Code/CodeElem">					
 							<div class="CodeExample">
 								<xsl:choose>
									<xsl:when test="../../../@Status='Ill-formed'">
										<xsl:text>* </xsl:text>
									</xsl:when>
									<xsl:when test="../../../@Status='Questionable'">
										<xsl:text>? </xsl:text>
									</xsl:when>
								</xsl:choose>
 								<xsl:value-of select="."/>
 							</div>
 						</xsl:for-each>
 					</xsl:when>
 					<xsl:otherwise>
<!-- Block, aber keine CodeElems -->
						<div class="CodeExample">
							<xsl:choose>
								<xsl:when test="@Status='Ill-formed'">
									<xsl:text>* </xsl:text>
								</xsl:when>
								<xsl:when test="@Status='Questionable'">
									<xsl:text>? </xsl:text>
								</xsl:when>
							</xsl:choose>
							<xsl:value-of select="."/>
						</div> 					
 					</xsl:otherwise>			
 				</xsl:choose>				
 			</xsl:when>
 			<xsl:otherwise>
<!-- wenn es Inline ist -->
				<div class="CodeExample">
					<xsl:choose>
						<xsl:when test="@Status='Ill-formed'">
							<xsl:text>* </xsl:text>
						</xsl:when>
						<xsl:when test="@Status='Questionable'">
							<xsl:text>? </xsl:text>
						</xsl:when>
					</xsl:choose>
					<xsl:value-of select="."/>
				</div> 				
 			</xsl:otherwise>
 		</xsl:choose>
 	</xsl:template>
 	 	
 	<xsl:template match="List">
 		<xsl:choose>
			<xsl:when test="@Type='Ordered'">
				<xsl:for-each select="Title">
					<br/>
					<xsl:apply-templates select="."/>
				</xsl:for-each>	
				<ol>
					<xsl:apply-templates select="Item"/>
 				</ol>
 			</xsl:when>	
 			<xsl:otherwise>
			<xsl:for-each select="Title">
				<br/>
				<xsl:apply-templates select="."/>
			</xsl:for-each>	
 			<ul>
 				<xsl:apply-templates select="Item"/>
 			</ul>
 			</xsl:otherwise>
 		</xsl:choose>
 	</xsl:template>	
 	
 	<xsl:template match="Item">
		<li>
		<xsl:apply-templates/>
		</li>
	</xsl:template>
	
	<xsl:template match="Formula">
		<xsl:choose>
 			<xsl:when test="@Display='Block'">
 				<div class="FormulaBlock">
 					<xsl:if test="@Id">
 						<xsl:attribute name="id">
 							<xsl:value-of select="@Id"/>
 						</xsl:attribute>
 					</xsl:if>
 					<xsl:copy-of select="node()"/>
 					<xsl:if test="@Id">
 						<span class="Label">
 							<xsl:text>(</xsl:text>
 							<xsl:choose>
 								<xsl:when test="@Information_Link">
 									<a target="_blank">
 										<xsl:attribute name="href">
 											<xsl:value-of select="@Information_Link"/>
 										</xsl:attribute>
 										<xsl:value-of select="@Id"/>
 									</a>
 								</xsl:when>
 								<xsl:when test="@Information_Ref">
 									<a>
 										<xsl:attribute name="href">
 											<xsl:value-of select="@Information_Ref"/>
 										</xsl:attribute>
 										<xsl:value-of select="@Id"/>
 									</a>
 								</xsl:when>
 								<xsl:otherwise>
 									<xsl:value-of select="@Id"/>
 								</xsl:otherwise>
 							</xsl:choose>
 							<xsl:text>)</xsl:text>
 						</span>
 					</xsl:if>
 				</div>
 			</xsl:when>
 			<xsl:otherwise>
 				<span class="Formula">
 					<xsl:if test="@Id">
 						<xsl:attribute name="id">
 							<xsl:value-of select="@Id"/>
 						</xsl:attribute>
 					</xsl:if>
 					<xsl:copy-of select="node()"/>
 				</span>
 			</xsl:otherwise>
 		</xsl:choose>
	</xsl:template>
	
<!-- Innerhalb eines LearningObjects werden die Tabellen automatisch durchnummeriert -->
<!-- Attribute werden nach HTML durchgereicht -->
	<xsl:template match="Table">
		<xsl:for-each select="Title">
			<xsl:value-of select="."/>
		<br/>
		</xsl:for-each>
		<table>
		<xsl:for-each select="@Width">
			<xsl:attribute name="width">
				<xsl:value-of select="."/>
			</xsl:attribute>
		</xsl:for-each>
		<xsl:for-each select="@Height">
			<xsl:attribute name="height">
				<xsl:value-of select="."/>
			</xsl:attribute>
		</xsl:for-each>
		<xsl:for-each select="@Border">
			<xsl:attribute name="border">
				<xsl:value-of select="."/>
			</xsl:attribute>
		</xsl:for-each>
		<xsl:if test="Summary">
			<xsl:attribute name="summary">
				<xsl:value-of select="Summary"/>
			</xsl:attribute>
		</xsl:if>
		<xsl:if test="HeaderCaption">
			<caption align="top">
			<xsl:choose>
			<xsl:when test="../@Language='de'">
			<xsl:text>Tabelle </xsl:text>
			</xsl:when>
			<xsl:when test="../@Language='en'">
			<xsl:text>Table </xsl:text>
			</xsl:when>
			</xsl:choose>
			<xsl:number count="Table"/><xsl:text>: </xsl:text>
			<xsl:value-of select="HeaderCaption"/>
			</caption>
		</xsl:if>
		<xsl:if test="FooterCaption">
			<caption align="bottom">
			<xsl:value-of select="FooterCaption"/>
			</caption>
		</xsl:if>
		<xsl:for-each select="TableRow">
			<tr>
				<xsl:for-each select="TableData">
					<td>
						<xsl:apply-templates/>
					</td>
				</xsl:for-each>
			</tr>
		</xsl:for-each>
		</table>
	</xsl:template>
	
	<xsl:template match="Glossary">
		<xsl:choose>
			<xsl:when test="../MetaData/General/Language='de'">
				<h1>Glossar</h1>
			</xsl:when>
			<xsl:when test="../MetaData/General/Language='en'">
				<h1>Glossary</h1>
			</xsl:when>
		</xsl:choose>
		<table width="90%">
		<xsl:for-each select="GlossaryItem">
			<tr>
			<xsl:attribute name="id">
			<xsl:value-of select="GlossaryTerm/@Definition"/>
			</xsl:attribute>
				<xsl:for-each select="GlossaryTerm">
					<td valign="top"><xsl:value-of select="."/></td>
				</xsl:for-each>
				<xsl:for-each select="DefinitionList">
					<td>
						<xsl:for-each select="Definition">
							<xsl:apply-templates/>
						</xsl:for-each>
					</td>
				</xsl:for-each>
				<xsl:for-each select="Definition">
					<td valign="top"><xsl:apply-templates select="."/></td>
				</xsl:for-each>
			</tr>
		</xsl:for-each>
		</table>
	</xsl:template>
	
	<xsl:template match="GlossaryTerm">
		<a class="GlossaryTerm">
			<xsl:attribute name="title">
				<xsl:value-of select="id(@Definition)/."/>
			</xsl:attribute>
			<xsl:attribute name="href">
				<xsl:value-of select="concat(id(@Definition)/../../../MetaData/General/Identifier/@Entry,'.xhtml','#',@Definition)"/>
			</xsl:attribute>
			<xsl:apply-templates/>
		</a> 
	</xsl:template>
	
	<xsl:template match="Definition">
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="Reference">
		<xsl:choose>
			<xsl:when test="@Type='BibliographyEntry'">
				<a class="Reference">
					<xsl:attribute name="href">
						<xsl:value-of select="concat(id(@Reference_to)/../../MetaData/General/Identifier/@Entry,'.xhtml','#',@Reference_to)"/>
					</xsl:attribute>
					<xsl:choose>
 						<xsl:when test="id(@Reference_to)/Author">
 							<xsl:for-each select="id(@Reference_to)/Author">
 								<xsl:apply-templates select="Family"/>
 								<xsl:choose>
									<xsl:when test="position()!=last()">
										<xsl:text>, </xsl:text>
									</xsl:when>
								</xsl:choose> 				
							</xsl:for-each>
						</xsl:when>
						<xsl:when test="id(@Reference_to)/Editor">
							<xsl:for-each select="id(@Reference_to)/Editor">
								<xsl:apply-templates select="Family"/>
 								<xsl:choose>
									<xsl:when test="position()!=last()">
										<xsl:text>, </xsl:text>
									</xsl:when>
								</xsl:choose> 				
							</xsl:for-each>
							<xsl:text> (Hrsg.)</xsl:text>
						</xsl:when>
						<xsl:when test="id(@Reference_to)/Organization">
							<xsl:for-each select="id(@Reference_to)/Organization">
								<xsl:apply-templates select="."/>
 								<xsl:choose>
									<xsl:when test="position()!=last()">
										<xsl:text>, </xsl:text>
									</xsl:when>
								</xsl:choose> 				
							</xsl:for-each>
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Title"/>
						</xsl:when>
					</xsl:choose>
					<xsl:if test="id(@Reference_to)/Year">
						<xsl:text>, </xsl:text>
 						<xsl:apply-templates select="id(@Reference_to)/Year"/>
 					</xsl:if>
 					<xsl:if test="@Page">
 						<xsl:text>, S. </xsl:text>
 						<xsl:apply-templates select="@Page"/>
 					</xsl:if>
 				</a>
 			</xsl:when>
 			<xsl:when test="@Type='LearningObject'">
<!-- Verzweigung: Je nach AggregationLevel wird anders verfahren -->
 				<xsl:choose>
 					<xsl:when test="id(@Reference_to)/../@AggregationLevel='1'">
<!-- Level 1-LearningObjects --> 
<!-- Erster Schritt: Level 1-LO, auf die verwiesen wird, erhalten eine eigene XHTML-Datei -->
 						<xsl:variable name="LO1" select="concat(@Reference_to,'.xhtml')"/>
 						<xsl:document href="{$LO1}">
 							<html>
 								<head>
 									<title>
 										<xsl:value-of select="id(@Reference_to)/../Title"/>
 									</title> 
 									<link type="text/css" rel="stylesheet">
										<xsl:attribute name="href">
											<xsl:value-of select="id(@Reference_to)/../../../LayoutInformation/@CSS-URL"/>
										</xsl:attribute>
									</link>
 								</head>
 								<body>
<!-- Hier muss unterschieden werden - je nach Dateiformat kann img oder a gewaehlt werden -->
									<xsl:choose>
										<xsl:when test="id(@Reference_to)/../../Technical/@Format='image-gif'">
<!-- Einbinden der LOs, die GIF-Grafiken sind - per img-Tag -->	
											<img>
 												<xsl:attribute name="src">
 													<xsl:value-of select="id(@Reference_to)/../../Technical/Location"/>
 												</xsl:attribute>
 											</img>
<!-- Ausgabe des Titels und der Description -->																
		 									<div class="Image">
												<xsl:choose>
													<xsl:when test="id(@Reference_to)/../Language='de'">
														<xsl:text>Abbildung </xsl:text>
													</xsl:when>
													<xsl:otherwise>
														<xsl:text>Figure </xsl:text>
													</xsl:otherwise>
												</xsl:choose>
												<xsl:number count="LearningObject"/>
												<xsl:text>: </xsl:text>
												<xsl:value-of select="id(@Reference_to)/../Title"/>
											</div>
											<div class="Imagetext">
												<xsl:apply-templates select="id(@Reference_to)/../Description"/>
											</div> 											
										</xsl:when>
										<xsl:when test="id(@Reference_to)/../../Technical/@Format='image-jpeg'">
<!-- Einbinden der LOs, die JPEG-Grafiken sind - per img-Tag -->	
											<img>
 												<xsl:attribute name="src">
 													<xsl:value-of select="id(@Reference_to)/../../Technical/Location"/>
 												</xsl:attribute>
 											</img>
<!-- Ausgabe des Titels und der Description -->																
		 									<div class="Image">
												<xsl:choose>
													<xsl:when test="id(@Reference_to)/../Language='de'">
														<xsl:text>Abbildung </xsl:text>
													</xsl:when>
													<xsl:otherwise>
														<xsl:text>Figure </xsl:text>
													</xsl:otherwise>
												</xsl:choose>
												<xsl:number count="LearningObject"/>
												<xsl:text>: </xsl:text>
												<xsl:value-of select="id(@Reference_to)/../Title"/>
											</div>
											<div class="Imagetext">
												<xsl:apply-templates select="id(@Reference_to)/../Description"/>
											</div>
										</xsl:when>
										<xsl:when test="id(@Reference_to)/../../Technical/@Format='image-png'">
<!-- Einbinden der LOs, die PNG-Grafiken sind - per img-Tag -->	
											<img>
 												<xsl:attribute name="src">
 													<xsl:value-of select="id(@Reference_to)/../../Technical/Location"/>
 												</xsl:attribute>
 											</img>
<!-- Ausgabe des Titels und der Description -->																
		 									<div class="Image">
												<xsl:choose>
													<xsl:when test="id(@Reference_to)/../Language='de'">
														<xsl:text>Abbildung </xsl:text>
													</xsl:when>
													<xsl:otherwise>
														<xsl:text>Figure </xsl:text>
													</xsl:otherwise>
												</xsl:choose>
												<xsl:number count="LearningObject"/>
												<xsl:text>: </xsl:text>
												<xsl:value-of select="id(@Reference_to)/../Title"/>
											</div>
											<div class="Imagetext">
												<xsl:apply-templates select="id(@Reference_to)/../Description"/>
											</div>
										</xsl:when>
										<xsl:when test="id(@Reference_to)/../../Technical/@Format='image-svg-xml'">
											<xsl:copy-of select="document(id(@Reference_to)/../../Technical/Location)/*"/>
<!-- Ausgabe des Titels und der Description -->																
		 									<div class="Image">
												<xsl:choose>
													<xsl:when test="id(@Reference_to)/../Language='de'">
														<xsl:text>Abbildung </xsl:text>
													</xsl:when>
													<xsl:otherwise>
														<xsl:text>Figure </xsl:text>
													</xsl:otherwise>
												</xsl:choose>
												<xsl:number count="LearningObject"/>
												<xsl:text>: </xsl:text>
												<xsl:value-of select="id(@Reference_to)/../Title"/>
											</div>
											<div class="Imagetext">
												<xsl:apply-templates select="id(@Reference_to)/../Description"/>
											</div>
										</xsl:when>
										<xsl:otherwise>
<!-- LOs, die keine Grafiken sind, werden per a eingebunden -->
											<a class="Image">
 												<xsl:attribute name="href">
 													<xsl:value-of select="id(@Reference_to)/../../Technical/Location"/>
 												</xsl:attribute>
 												<xsl:value-of select="id(@Reference_to)/../Title"/>
 											</a>
 											<div class="Imagetext">
												<xsl:apply-templates select="id(@Reference_to)/../Description"/>
											</div>							
										</xsl:otherwise>
									</xsl:choose> 		
 								</body>
 							</html>
 						</xsl:document>
<!-- Zweiter Schritt: Einbau der Referenz auf die soeben erzeugte XHTML-Datei --> 						
						<xsl:choose>
							<xsl:when test="id(@Reference_to)/../../Technical/@Format='image-gif'">
<!-- Einfuegen der Typ-Grafik entsprechend des Multimedia-Objekts -->								
								<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="40px" height="40px">
									<rect id="quadrat" stroke="black" fill="none" y="5px" x="5px" width="30px" height="30px" stroke-width="2px"/>
									<text y="23px" x="10px" style="font-size:10pt">GIF</text>
								</svg>
								<a target="_blank">
 									<xsl:attribute name="href">
 										<xsl:value-of select="concat(@Reference_to,'.xhtml')"/>
 									</xsl:attribute>									 									
 									<xsl:text>>> </xsl:text>
 									<xsl:value-of select="id(@Reference_to)/../Title"/>
 								</a>
							</xsl:when>
							<xsl:when test="id(@Reference_to)/../../Technical/@Format='image-jpeg'">
								<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="40px" height="40px">
									<rect id="quadrat" stroke="black" fill="none" y="5px" x="5px" width="30px" height="30px" stroke-width="2px"/>
									<text y="23px" x="9px" style="font-size:10pt">JPG</text>
								</svg>
								<a target="_blank">
 									<xsl:attribute name="href">
 										<xsl:value-of select="concat(@Reference_to,'.xhtml')"/>
 									</xsl:attribute>
 									<xsl:text> >> </xsl:text>
 									<xsl:value-of select="id(@Reference_to)/../Title"/>
 								</a>
							</xsl:when>
							<xsl:when test="id(@Reference_to)/../../Technical/@Format='image-png'">
								<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="40px" height="40px">
									<rect id="quadrat" stroke="black" fill="none" y="5px" x="5px" width="30px" height="30px" stroke-width="2px"/>
									<text y="23px" x="10px" style="font-size:10pt">PNG</text>
								</svg>
								<a target="_blank">
 									<xsl:attribute name="href">
 										<xsl:value-of select="concat(@Reference_to,'.xhtml')"/>
 									</xsl:attribute>
 									<xsl:text> >> </xsl:text>
 									<xsl:value-of select="id(@Reference_to)/../Title"/>
 								</a>
							</xsl:when>
<!-- um Audiodaten mit einer Typ-Grafik zu versehen, muessen hier weitere Unterscheidungen gemacht werden - je nach MIME-Typ -->
							<xsl:otherwise>
<!-- Behandlung von Level 1 LOs, die nicht Grafik sind -->
								<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="40px" height="40px">
									<rect id="quadrat" stroke="black" fill="none" y="5px" x="5px" width="30px" height="30px" stroke-width="2px"/>
									<text y="23px" x="10px" style="font-size:10pt">???</text>
								</svg>
								<a target="_blank">
 									<xsl:attribute name="href">
 										<xsl:value-of select="concat(@Reference_to,'.xhtml')"/>
 									</xsl:attribute>
 									<xsl:text> >> </xsl:text>
 									<xsl:value-of select="id(@Reference_to)/../Title"/>
 								</a>						
							</xsl:otherwise>
						</xsl:choose> 					
 					</xsl:when>
<!-- Ende von Behandlung von Level 1 LOs -->
					<xsl:otherwise>
<!-- Level 2 oder 3 LOs, auf die referenziert wird -->
						<a>
 							<xsl:attribute name="href">
 								<xsl:value-of select="concat(@Reference_to,'.xhtml')"/>
 							</xsl:attribute>
 							<xsl:text>>> </xsl:text>
 							<xsl:value-of select="id(@Reference_to)/../Title"/>
 						</a>
					</xsl:otherwise> 					
<!-- Ende von Behandlung von Level 2 oder 3 LOs -->					
 				</xsl:choose>
 			</xsl:when>
<!-- Ende der Verarbeitung von LearningObjects -->
 			<xsl:when test="@Type='Example'">
 				<a class="Reference">
					<xsl:attribute name="href">
						<xsl:choose>
							<xsl:when test="name(id(@Reference_to)/../..)='Item'">
								<xsl:value-of select="concat(id(@Reference_to)/../../../../../../../MetaData/General/Identifier/@Entry,'.xhtml','#',@Reference_to)"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="concat(id(@Reference_to)/../../../../MetaData/General/Identifier/@Entry,'.xhtml','#',@Reference_to)"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:text>> </xsl:text>
<!-- Abfrage nach der verwendeten Sprache noch einfuegen! -->
					<xsl:choose>
						<xsl:when test="../@Language='de'">
							<xsl:text>Beispiel </xsl:text>
						</xsl:when>
					</xsl:choose>
					<xsl:number count="Example" level="any"/>
					<xsl:text>: </xsl:text>
					<xsl:value-of select="@Reference_to"/>
					<xsl:apply-templates/>
				</a>
 			</xsl:when>
 			<xsl:otherwise>
<!-- Referenz auf eine Stelle im Text --> 			
				<a class="Reference">
					<xsl:attribute name="href">
						<xsl:choose>
							<xsl:when test="name(id(@Reference_to)/../..)='Item'">
								<xsl:value-of select="concat(id(@Reference_to)/../../../../../../../MetaData/General/Identifier/@Entry,'.xhtml','#',@Reference_to)"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="concat(id(@Reference_to)/../../../../MetaData/General/Identifier/@Entry,'.xhtml','#',@Reference_to)"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:text>></xsl:text>
					<xsl:apply-templates/>
				</a>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="RefTarget">
		<span>
		<xsl:attribute name="id">
			<xsl:value-of select="@Id"/>
		</xsl:attribute>
		<xsl:apply-templates/>
		</span>
	</xsl:template>
	
	<xsl:template match="Examples">
		<p>
			<xsl:apply-templates/>
		</p>
	</xsl:template>
	
	<xsl:template match="Example">
		<div class="Example">
			<xsl:choose>
				<xsl:when test="//MetaData/General/Language='de'">
					<xsl:text>Beispiel </xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>Example</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:number count="Example" level="any"/>
			<xsl:text>: </xsl:text>
			<xsl:value-of select="@Id"/>
			<xsl:text> </xsl:text>
		</div>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="Example/*">
		<div class="ExampleText">
			<xsl:choose>
				<xsl:when test="../@Status='Ill-formed'">
					<xsl:text>* </xsl:text>
				</xsl:when>
				<xsl:when test="../@Status='Questionable'">
					<xsl:text>? </xsl:text>
				</xsl:when>
			</xsl:choose>
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="Gloss">
		<span class="Indent"><xsl:apply-templates/></span>
	</xsl:template>
	
	<xsl:template match="Formalisation">
		<span class="Indent"><xsl:apply-templates/></span>
	</xsl:template>
	
	<xsl:template match="Transcription">
		<span class="Indent"><xsl:apply-templates/></span>
	</xsl:template>
	
	<xsl:template match="Translation">
		<span class="Indent"><xsl:apply-templates/></span>
	</xsl:template>
	
	<xsl:template match="Bibliography">
		<xsl:choose>
			<xsl:when test="../MetaData/General/Language='de'">
				<h1>Literaturangaben</h1>
			</xsl:when>
			<xsl:when test="../MetaData/General/Language='en'">
				<h1>Literature</h1>
			</xsl:when>
		</xsl:choose>
		<xsl:for-each select="Bibitem">
		<xsl:sort select="Author/Family"/>
		<p>
		<xsl:apply-templates select="."/>
		</p>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="Bibitem">
		<a>
			<xsl:attribute name="id">
				<xsl:value-of select="@Label"/>
			</xsl:attribute>
			<xsl:choose>
				<xsl:when test="Author">
					<xsl:for-each select="Author">
						<xsl:apply-templates select="Family"/>
						<xsl:if test="Given | Other | Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="Given"/>
							<xsl:if test="Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="Other"/>
							</xsl:if>
							<xsl:if test="Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="Suffix"/>
							</xsl:if>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="position()=last()">
								<xsl:text>, </xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>/</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:when>
				<xsl:when test="Editor">
					<xsl:for-each select="Editor">
						<xsl:apply-templates select="Family"/>
						<xsl:if test="Given | Other | Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="Given"/>
							<xsl:if test="Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="Other"/>
							</xsl:if>
							<xsl:if test="Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="Suffix"/>
							</xsl:if>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="position()=last()">
								<xsl:text> (Hrsg.), </xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>/</xsl:text>
							</xsl:otherwise>
						</xsl:choose>			
					</xsl:for-each>
				</xsl:when>
				<xsl:when test="Organization">
					<xsl:apply-templates select="Organization"/>
					<xsl:text>, </xsl:text>
				</xsl:when>
			</xsl:choose>	
		</a>
		<xsl:text> "</xsl:text>
		<xsl:choose>
			<xsl:when test="@Type='Internet'">
				<xsl:value-of select="Title"/>
				<xsl:text>".</xsl:text>
				<br/>
				<xsl:if test="Edition">
					<xsl:value-of select="Edition"/>
					<br/>
				</xsl:if>
				<xsl:if test="Publisher">
					<xsl:apply-templates select="Publisher"/>
					<xsl:text>, </xsl:text>	
				</xsl:if>
				<xsl:for-each select="URL">
					<a>
						<xsl:attribute name="href">
							<xsl:value-of select="."/>
						</xsl:attribute>
						<xsl:value-of select="."/>
					</a>
					<xsl:if test="position()!=last()">
						<xsl:text>, </xsl:text>
					</xsl:if>
				</xsl:for-each>
				<xsl:if test="Year">
					<xsl:text>, </xsl:text>
					<xsl:value-of select="Year"/>
				</xsl:if>
				<xsl:text>.</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="Title"/>
				<xsl:value-of select="Booktitle"/>
				<xsl:text>".</xsl:text>
				<br/>
				<xsl:if test="Edition">
					<xsl:value-of select="Edition"/>
					<br/>
				</xsl:if>
				<xsl:if test="Publisher">
					<xsl:apply-templates select="Publisher"/>
					<xsl:text>, </xsl:text>	
				</xsl:if>
				<xsl:value-of select="Address"/>
				<xsl:text>, </xsl:text>
				<xsl:value-of select="Year"/>
				<xsl:text>.</xsl:text>
			</xsl:otherwise>
		</xsl:choose>		
	</xsl:template>
	
	<!-- nur fuer interne Testzwecke -->
	
	<xsl:template match="Test">
		<xsl:if test="TestItem">
			<h1>Test</h1>
		</xsl:if>
		<xsl:for-each select="TestItem">
			<xsl:apply-templates/>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="Question">
		<p>
			<b><xsl:apply-templates/></b>
		</p>
	</xsl:template>
	
	<xsl:template match="Comment">
		<span class="Comment">
			<xsl:apply-templates/>
			<xsl:if test="@Annotator">
				<b><xsl:text> Anmerkung von: </xsl:text>
				<xsl:value-of select="@Annotator"/></b>
			</xsl:if>
		</span>
	</xsl:template>

</xsl:stylesheet>